@@ -48,13 +48,14 @@ from datalad.support.constraints import (
 from datalad.support.exceptions import DownloadError
 from datalad.support.param import Parameter
 from datalad.support.network import (
-    get_local_file_url,
-    download_url,
-    is_url,
-    URL,
-    RI,
     DataLadRI,
     PathRI,
+    RI,
+    SSHRI,
+    URL,
+    download_url,
+    get_local_file_url,
+    is_url,
 )
 from datalad.dochelpers import (
     exc_str,
@@ -215,7 +216,7 @@ class Clone(Interface):
         # if we got a dataset, path will be resolved against it.
         # Otherwise path will be resolved first.
         ds = require_dataset(
-            dataset, check_installed=True, purpose='cloning') \
+            dataset, check_installed=True, purpose='clone') \
             if dataset is not None else dataset
         refds_path = ds.path if ds else None
 
@@ -535,8 +536,22 @@ def clone_dataset(
         return
 
     dest_repo = destds.repo
+
+    remotes = dest_repo.get_remotes(with_urls_only=True)
+    nremotes = len(remotes)
+    if nremotes == 1:
+        remote = remotes[0]
+        lgr.debug("Determined %s to be remote of %s", remote, destds)
+    elif remotes > 1:
+        lgr.warning(
+            "Fresh clone %s unexpected has multiple remotes: %s. Using %s",
+            destds.path, remotes, remotes[0])
+        remote = remotes[0]
+    else:
+        raise RuntimeError("bug: fresh clone has zero remotes")
+
     if not cand.get("version"):
-        postclone_check_head(destds)
+        postclone_check_head(destds, remote=remote)
 
     # act on --reckless=shared-...
     # must happen prior git-annex-init, where we can cheaply alter the repo
@@ -547,17 +562,19 @@ def clone_dataset(
 
     # In case of RIA stores we need to prepare *before* annex is called at all
     if result_props['source']['type'] == 'ria':
-        postclone_preannex_cfg_ria(destds)
+        postclone_preannex_cfg_ria(destds, remote=remote)
 
     yield from postclonecfg_annexdataset(
         destds,
         reckless,
-        description)
+        description,
+        remote=remote)
 
     if checkout_gitsha and \
        dest_repo.get_hexsha(dest_repo.get_corresponding_branch()) != checkout_gitsha:
         try:
-            postclone_checkout_commit(dest_repo, checkout_gitsha)
+            postclone_checkout_commit(dest_repo, checkout_gitsha,
+                                      remote=remote)
         except Exception as e:
             yield get_status_dict(
                 status='error',
@@ -578,7 +595,8 @@ def clone_dataset(
     # perform any post-processing that needs to know details of the clone
     # source
     if result_props['source']['type'] == 'ria':
-        yield from postclonecfg_ria(destds, result_props['source'])
+        yield from postclonecfg_ria(destds, result_props['source'],
+                                    remote=remote)
 
     if reckless:
         # store the reckless setting in the dataset to make it
@@ -600,7 +618,7 @@ def clone_dataset(
     yield get_status_dict(status='ok', **result_props)
 
 
-def postclone_checkout_commit(repo, target_commit):
+def postclone_checkout_commit(repo, target_commit, remote="origin"):
     """Helper to check out a specific target commit in a fresh clone.
 
     Will not check (again) if current commit and target commit are already
@@ -618,7 +636,7 @@ def postclone_checkout_commit(repo, target_commit):
     # local check
     if not repo.commit_exists(target_commit):
         try:
-            repo.fetch(remote='origin', refspec=target_commit)
+            repo.fetch(remote=remote, refspec=target_commit)
         except CommandError:
             pass
         # instead of inspecting the fetch results for possible ways
@@ -632,7 +650,7 @@ def postclone_checkout_commit(repo, target_commit):
             # and not another blind attempt
             raise ValueError(
                 'Target commit %s does not exist in the clone, and '
-                'a fetch that commit from origin failed'
+                'a fetch that commit from remote failed'
                 % target_commit[:8])
     # checkout the desired commit
     repo.call_git(['checkout', target_commit])
@@ -666,7 +684,7 @@ def postclone_checkout_commit(repo, target_commit):
                 repo, target_commit[:8], repo_orig_branch)
 
 
-def postclone_check_head(ds):
+def postclone_check_head(ds, remote="origin"):
     repo = ds.repo
     if not repo.commit_exists("HEAD"):
         # HEAD points to an unborn branch. A likely cause of this is that the
@@ -682,16 +700,17 @@ def postclone_check_head(ds):
         remote_branches = (
             b["refname:strip=2"] for b in repo.for_each_ref_(
                 fields="refname:strip=2", sort="-committerdate",
-                pattern="refs/remotes/origin"))
+                pattern="refs/remotes/" + remote))
         for rbranch in remote_branches:
-            if rbranch in ["origin/git-annex", "HEAD"]:
+            if rbranch in [remote + "/git-annex", "HEAD"]:
                 continue
-            if rbranch.startswith("origin/adjusted/"):
+            if rbranch.startswith(remote + "/adjusted/"):
                 # If necessary for this file system, a downstream
                 # git-annex-init call will handle moving into an
                 # adjusted state.
                 continue
-            repo.call_git(["checkout", "-b", rbranch[7:],  # drop "origin/"
+            repo.call_git(["checkout", "-b",
+                           rbranch[len(remote) + 1:],  # drop "<remote>/"
                            "--track", rbranch])
             lgr.debug("Checked out local branch from %s", rbranch)
             return
@@ -699,12 +718,12 @@ def postclone_check_head(ds):
                     "with commits", ds.path)
 
 
-def postclone_preannex_cfg_ria(ds):
+def postclone_preannex_cfg_ria(ds, remote="origin"):
 
-    # We need to annex-ignore origin before annex-init is called on the clone,
+    # We need to annex-ignore the remote before annex-init is called on the clone,
     # due to issues 5186 and 5253 (and we would have done it afterwards anyway).
     # annex/objects in RIA stores is special for several reasons.
-    # 1. 'origin' doesn't know about it (no actual local annex for origin)
+    # 1. the remote doesn't know about it (no actual local annex for the remote)
     # 2. RIA may use hashdir mixed, copying data to it via git-annex (if cloned
     #    via ssh or local) would make it see a bare repo and establish a
     #    hashdir lower annex object tree.
@@ -715,56 +734,24 @@ def postclone_preannex_cfg_ria(ds):
     # store could also hold simple standard annexes w/o an intended ORA remote.
     # This needs the introduction of a new version label in RIA datasets, making
     # the following call conditional.
-    ds.config.set('remote.origin.annex-ignore', 'true', where='local')
+    ds.config.set(f'remote.{remote}.annex-ignore', 'true', where='local')
 
 
-def postclonecfg_ria(ds, props):
+def postclonecfg_ria(ds, props, remote="origin"):
     """Configure a dataset freshly cloned from a RIA store"""
     repo = ds.repo
-    RIA_REMOTE_NAME = 'origin'  # don't hardcode everywhere
-
-    # chances are that if this dataset came from a RIA store, its subdatasets
-    # may live there too. Place a subdataset source candidate config that makes
-    # get probe this RIA store when obtaining subdatasets
-    ds.config.set(
-        # we use the label 'origin' for this candidate in order to not have to
-        # generate a complicated name from the actual source specification.
-        # we pick a cost of 200 to sort it before datalad's default candidates
-        # for non-RIA URLs, because they prioritize hierarchical layouts that
-        # cannot be found in a RIA store
-        'datalad.get.subdataset-source-candidate-200origin',
-        # use the entire original URL, up to the fragment + plus dataset ID
-        # placeholder, this should make things work with any store setup we
-        # support (paths, ports, ...)
-        props['source'].split('#', maxsplit=1)[0] + '#{id}',
-        where='local')
-
-    # setup publication dependency, if a corresponding special remote exists
-    # and was enabled (there could be RIA stores that actually only have repos)
-    # make this function be a generator
-    ora_remotes = [s for s in ds.siblings('query', result_renderer='disabled')
-                   if s.get('annex-externaltype') == 'ora']
-    if not ora_remotes and any(
-            r.get('externaltype') == 'ora'
-            for r in (repo.get_special_remotes().values()
-                      if hasattr(repo, 'get_special_remotes')
-                      else [])):
-        # no ORA remote autoenabled, but configuration known about at least one.
-        # Let's check origin's config for datalad.ora-remote.uuid as stored by
-        # create-sibling-ria and enable try enabling that one.
-        lgr.debug("Found no autoenabled ORA special remote. Trying to look it "
-                  "up in source config ...")
 
+    def get_uuid_from_store(store_url):
         # First figure whether we cloned via SSH, HTTP or local path and then
         # get that config file the same way:
         config_content = None
-        scheme = props['giturl'].split(':', 1)[0]
+        scheme = store_url.split(':', 1)[0]
         if scheme in ['http', 'https']:
             try:
                 config_content = download_url(
                     "{}{}config".format(
-                        props['giturl'],
-                        '/' if not props['giturl'].endswith('/') else ''))
+                        store_url,
+                        '/' if not store_url.endswith('/') else ''))
             except DownloadError as e:
                 lgr.debug("Failed to get config file from source:\n%s",
                           exc_str(e))
@@ -772,9 +759,9 @@ def postclonecfg_ria(ds, props):
             # TODO: switch the following to proper command abstraction:
             # SSHRemoteIO ignores the path part ATM. No remote CWD! (To be
             # changed with command abstractions). So we need to get that part to
-            # have a valid path to origin's config file:
-            cfg_path = PurePosixPath(URL(props['giturl']).path) / 'config'
-            op = SSHRemoteIO(props['giturl'])
+            # have a valid path to the remote's config file:
+            cfg_path = PurePosixPath(URL(store_url).path) / 'config'
+            op = SSHRemoteIO(store_url)
             try:
                 config_content = op.read_file(cfg_path)
             except RIARemoteError as e:
@@ -784,7 +771,7 @@ def postclonecfg_ria(ds, props):
         elif scheme == 'file':
             # TODO: switch the following to proper command abstraction:
             op = LocalIO()
-            cfg_path = Path(URL(props['giturl']).localpath) / 'config'
+            cfg_path = Path(URL(store_url).localpath) / 'config'
             try:
                 config_content = op.read_file(cfg_path)
             except (RIARemoteError, OSError) as e:
@@ -794,8 +781,8 @@ def postclonecfg_ria(ds, props):
             lgr.debug("Unknown URL-Scheme %s in %s. Can handle SSH, HTTP or "
                       "FILE scheme URLs.", scheme, props['source'])
 
-        # 3. And read it
-        org_uuid = None
+        # And read it
+        uuid = None
         if config_content:
             # TODO: We might be able to spare the saving to a file.
             #       "git config -f -" is not explicitly documented but happens
@@ -809,17 +796,60 @@ def postclonecfg_ria(ds, props):
                          'datalad.ora-remote.uuid'],
                         protocol=StdOutCapture
                     )
-                    org_uuid = result['stdout'].strip()
+                    uuid = result['stdout'].strip()
                 except CommandError as e:
                     # doesn't contain what we are looking for
                     lgr.debug("Found no UUID for ORA special remote at "
-                              "'%s' (%s)", RIA_REMOTE_NAME, exc_str(e))
+                              "'%s' (%s)", remote, exc_str(e))
+
+        return uuid
+
+
+
+
+    # chances are that if this dataset came from a RIA store, its subdatasets
+    # may live there too. Place a subdataset source candidate config that makes
+    # get probe this RIA store when obtaining subdatasets
+    ria_store_url = props['source'].split('#', maxsplit=1)[0]
+    ds.config.set(
+        # we use the label 'origin' for this candidate in order to not have to
+        # generate a complicated name from the actual source specification.
+        # we pick a cost of 200 to sort it before datalad's default candidates
+        # for non-RIA URLs, because they prioritize hierarchical layouts that
+        # cannot be found in a RIA store
+        'datalad.get.subdataset-source-candidate-200origin',
+        # use the entire original URL, up to the fragment + plus dataset ID
+        # placeholder, this should make things work with any store setup we
+        # support (paths, ports, ...)
+        ria_store_url + '#{id}',
+        where='local')
+
+    # setup publication dependency, if a corresponding special remote exists
+    # and was enabled (there could be RIA stores that actually only have repos)
+    # make this function be a generator
+    ora_remotes = [s for s in ds.siblings('query', result_renderer='disabled')
+                   if s.get('annex-externaltype') == 'ora']
+    # get full special remotes' config for access to stored URL
+    srs = repo.get_special_remotes() \
+        if hasattr(repo, 'get_special_remotes') else dict()
+
+    if (not ora_remotes and any(
+            r.get('externaltype') == 'ora' for r in srs.values())) or \
+            all(not srs[r['annex-uuid']]['url'].startswith(ria_store_url)
+                for r in ora_remotes):
+        # No ORA remote autoenabled, but configuration known about at least one,
+        # or enabled ORA remotes seem to not match clone URL.
+        # Let's check the remote's config for datalad.ora-remote.uuid as stored by
+        # create-sibling-ria and enable try enabling that one.
+        lgr.debug("Found no autoenabled ORA special remote. Trying to look it "
+                  "up in source config ...")
+
+        org_uuid = get_uuid_from_store(props['giturl'])
 
         # Now, enable it. If annex-init didn't fail to enable it as stored, we
         # wouldn't end up here, so enable with store URL as suggested by the URL
         # we cloned from.
         if org_uuid:
-            srs = repo.get_special_remotes()
             if org_uuid in srs.keys():
                 # TODO: - Double-check autoenable value and only do this when
                 #         true?
@@ -846,24 +876,67 @@ def postclonecfg_ria(ds, props):
                               exc_str(e))
             else:
                 lgr.debug("Unknown ORA special remote uuid at '%s': %s",
-                          RIA_REMOTE_NAME, org_uuid)
+                          remote, org_uuid)
+
+    # Set publication dependency for `remote` on the respective ORA remote:
     if ora_remotes:
-        if len(ora_remotes) == 1:
+        url_matching_remotes = [r for r in ora_remotes
+                                if srs[r['annex-uuid']]['url'] == ria_store_url]
+
+        if len(url_matching_remotes) == 1:
+            # We have exactly one ORA remote with the same store URL we used for
+            # cloning (includes previously reconfigured remote).
+            # Set publication dependency:
             yield from ds.siblings('configure',
-                                   name=RIA_REMOTE_NAME,
-                                   publish_depends=ora_remotes[0]['name'],
+                                   name=remote,
+                                   publish_depends=url_matching_remotes[0]['name'],
                                    result_filter=None,
                                    result_renderer='disabled')
+
+        elif not url_matching_remotes:
+            # No matches but we have successfully autoenabled ORA remotes. Could
+            # be the same store accessed by different method (cloning via HTTP
+            # but special remote access via SSH). We can confidently set
+            # publication dependency if the store knows the UUID.
+            org_uuid = get_uuid_from_store(props['giturl'])
+            uuid_matching_remotes = [r for r in ora_remotes
+                                     if r['annex-uuid'] == org_uuid]
+            if uuid_matching_remotes:
+                # Multiple uuid matches are actually possible via same-as.
+                # However, in that case we can't decide which one is supposed to
+                # be used with publishing to `remote`.
+                if len(uuid_matching_remotes) == 1:
+                    yield from ds.siblings(
+                        'configure',
+                        name=remote,
+                        publish_depends=uuid_matching_remotes[0]['name'],
+                        result_filter=None,
+                        result_renderer='disabled')
+                else:
+                    lgr.warning(
+                        "Found multiple matching ORA remotes. Couldn't decide "
+                        "which one publishing to '%s' should depend on: %s."
+                        " Consider running 'datalad siblings configure -s "
+                        "%s --publish-depends ORAREMOTENAME' to set "
+                        "publication dependency manually.",
+                        remote,
+                        [r['name'] for r in uuid_matching_remotes],
+                        remote)
+
         else:
-            lgr.warning("Found multiple ORA remotes. Couldn't decide which "
-                        "publishing to 'origin' should depend on: %s. Consider "
-                        "running 'datalad siblings configure -s origin "
-                        "--publish-depends ORAREMOTENAME' to set publication "
-                        "dependency manually.",
-                        [r['name'] for r in ora_remotes])
+            # We have multiple ORA remotes with the same store URL we cloned
+            # from.
+            lgr.warning("Found multiple matching ORA remotes. Couldn't decide "
+                        "which one publishing to '%s' should depend on: %s."
+                        " Consider running 'datalad siblings configure -s "
+                        "%s --publish-depends ORAREMOTENAME' to set "
+                        "publication dependency manually.",
+                        remote,
+                        [r['name'] for r in url_matching_remotes],
+                        remote)
 
 
-def postclonecfg_annexdataset(ds, reckless, description=None):
+def postclonecfg_annexdataset(ds, reckless, description=None, remote="origin"):
     """If ds "knows annex" -- annex init it, set into reckless etc
 
     Provides additional tune up to a possibly an annex repo, e.g.
@@ -898,9 +971,9 @@ def postclonecfg_annexdataset(ds, reckless, description=None):
 
     elif reckless == 'ephemeral':
         # with ephemeral we declare 'here' as 'dead' right away, whenever
-        # we symlink origin's annex, since availability from 'here' should
+        # we symlink the remote's annex, since availability from 'here' should
         # not be propagated for an ephemeral clone when we publish back to
-        # origin.
+        # the remote.
         # This will cause stuff like this for a locally present annexed file:
         # % git annex whereis d1
         # whereis d1 (0 copies) failed
@@ -909,9 +982,9 @@ def postclonecfg_annexdataset(ds, reckless, description=None):
         # % git annex find . --in here
         # d1
 
-        # we don't want annex copy-to origin
+        # we don't want annex copy-to <remote>
         ds.config.set(
-            'remote.origin.annex-ignore', 'true',
+            f'remote.{remote}.annex-ignore', 'true',
             where='local')
 
         ds.repo.set_remote_dead('here')
@@ -920,7 +993,7 @@ def postclonecfg_annexdataset(ds, reckless, description=None):
                                     ds.repo.dot_git / 'dl_target_test'):
             # symlink the annex to avoid needless copies in an ephemeral clone
             annex_dir = ds.repo.dot_git / 'annex'
-            origin_annex_url = ds.config.get("remote.origin.url", None)
+            origin_annex_url = ds.config.get(f"remote.{remote}.url", None)
             origin_git_path = None
             if origin_annex_url:
                 try:
@@ -943,9 +1016,9 @@ def postclonecfg_annexdataset(ds, reckless, description=None):
                     # symlinking .git/annex. It might still make sense to
                     # have an ephemeral clone that doesn't propagate its avail.
                     # info. Therefore don't fail altogether.
-                    lgr.warning("reckless=ephemeral mode: origin doesn't seem "
+                    lgr.warning("reckless=ephemeral mode: %s doesn't seem "
                                 "local: %s\nno symlinks being used",
-                                origin_annex_url)
+                                remote, origin_annex_url)
             if origin_git_path:
                 # TODO make sure that we do not delete any unique data
                 rmtree(str(annex_dir)) \
@@ -1033,36 +1106,38 @@ def postclonecfg_annexdataset(ds, reckless, description=None):
             srs[False][0] if len(srs[False]) == 1 else "SIBLING",
         )
 
-    # we have just cloned the repo, so it has 'origin', configure any
+    # we have just cloned the repo, so it has a remote `remote`, configure any
     # reachable origin of origins
-    yield from configure_origins(ds, ds)
+    yield from configure_origins(ds, ds, remote=remote)
 
 
 _handle_possible_annex_dataset = postclonecfg_annexdataset
 
 
-def configure_origins(cfgds, probeds, label=None):
-    """Configure any discoverable local dataset 'origin' sibling as a remote
+def configure_origins(cfgds, probeds, label=None, remote="origin"):
+    """Configure any discoverable local dataset sibling as a remote
 
     Parameters
     ----------
     cfgds : Dataset
       Dataset to receive the remote configurations
     probeds : Dataset
-      Dataset to start looking for 'origin' remotes. May be identical with
+      Dataset to start looking for `remote` remotes. May be identical with
       `cfgds`.
     label : int, optional
-      Each discovered 'origin' will be configured as a remote under the name
-      'origin-<label>'. If no label is given, '2' will be used by default,
-      given that there is typically a 'origin' remote already.
+      Each discovered remote will be configured as a remote under the name
+      '<remote>-<label>'. If no label is given, '2' will be used by default,
+      given that there is typically a remote named `remote` already.
+    remote : str, optional
+      Name of the default remote on clone.
     """
     if label is None:
         label = 1
     # let's look at the URL for that remote and see if it is a local
     # dataset
-    origin_url = probeds.config.get('remote.origin.url')
+    origin_url = probeds.config.get(f'remote.{remote}.url')
     if not origin_url:
-        # no origin, nothing to do
+        # no remote with default name, nothing to do
         return
     if not cfgds.config.obtain(
             'datalad.install.inherit-local-origin',
@@ -1073,7 +1148,7 @@ def configure_origins(cfgds, probeds, label=None):
         # not local path
         return
 
-    # no need to reconfigure original/direct origin again
+    # no need to reconfigure original/direct remote again
     if cfgds != probeds:
         # prevent duplicates
         known_remote_urls = set(
@@ -1086,7 +1161,7 @@ def configure_origins(cfgds, probeds, label=None):
                 'configure',
                 # no chance for conflict, can only be the second configured
                 # remote
-                name='origin-{}'.format(label),
+                name='{}-{}'.format(remote, label),
                 url=origin_url,
                 # fetch to get all annex info
                 fetch=True,
@@ -1095,12 +1170,13 @@ def configure_origins(cfgds, probeds, label=None):
             )
     # and dive deeper
     # given the clone source is a local dataset, we can have a
-    # cheap look at it, and configure its own 'origin' as a remote
+    # cheap look at it, and configure its own `remote` as a remote
     # (if there is any), and benefit from additional annex availability
     yield from configure_origins(
         cfgds,
         Dataset(probeds.pathobj / origin_url),
-        label=label + 1)
+        label=label + 1,
+        remote=remote)
 
 
 def _get_tracking_source(ds):
@@ -1131,7 +1207,7 @@ def _get_installationpath_from_url(url):
     from a URL, analog to what `git clone` does.
     """
     ri = RI(url)
-    if isinstance(ri, (URL, DataLadRI)):  # decode only if URL
+    if isinstance(ri, (URL, DataLadRI, SSHRI)):  # decode only if URL
         path = ri.path.rstrip('/')
         path = urlunquote(path) if path else ri.hostname
         if '/' in path:
