@@ -57,6 +57,7 @@ from datalad.interface.common_opts import (
     inherit_opt,
     location_description,
 )
+from datalad.interface.utils import default_result_renderer
 from datalad.downloaders.credentials import UserPassword
 from datalad.distribution.dataset import (
     require_dataset,
@@ -148,9 +149,8 @@ class Siblings(Interface):
         action=Parameter(
             args=('action',),
             nargs='?',
-            metavar='ACTION',
             doc="""command action selection (see general documentation)""",
-            constraints=EnsureChoice('query', 'add', 'remove', 'configure', 'enable') | EnsureNone()),
+            constraints=EnsureChoice('query', 'add', 'remove', 'configure', 'enable')),
         url=Parameter(
             args=('--url',),
             doc="""the URL of or path to the dataset sibling named by
@@ -240,7 +240,7 @@ class Siblings(Interface):
         worker = action_worker_map[action]
 
         dataset = require_dataset(
-            dataset, check_installed=False, purpose='sibling configuration')
+            dataset, check_installed=False, purpose='configure sibling')
         refds_path = dataset.path
 
         res_kwargs = dict(refds=refds_path, logger=lgr)
@@ -312,7 +312,7 @@ class Siblings(Interface):
             )
             return
         if res['status'] != 'ok' or not res.get('action', '').endswith('-sibling') :
-            # logging complained about this already
+            default_result_renderer(res)
             return
         path = op.relpath(res['path'],
                        res['refds']) if res.get('refds', None) else res['path']
@@ -552,7 +552,7 @@ def _configure_remote(
                     "Could not enable annex remote %s. This is expected if %s "
                     "is a pure Git remote, or happens if it is not accessible.",
                     name, name)
-                lgr.debug("Exception was: %s" % exc_str(exc))
+                lgr.debug("Exception was: %s", exc_str(exc))
 
             if as_common_datasrc:
                 ri = RI(url)
