@@ -21,6 +21,7 @@ from requests.utils import parse_dict_header
 import io
 from time import sleep
 
+from .. import __version__
 from ..utils import (
     ensure_list_from_str,
     ensure_dict_from_str,
@@ -50,6 +51,13 @@ from logging import getLogger
 from ..log import LoggerHelper
 lgr = getLogger('datalad.http')
 
+# Following https://meta.wikimedia.org/wiki/User-Agent_policy to provide
+# extended and informative User-Agent string
+DEFAULT_USER_AGENT = \
+    f'DataLad/{__version__} ' \
+    '(https://datalad.org; team@datalad.org) ' \
+    f'python-requests/{requests.__version__}'
+
 try:
     import requests_ftp
     _FTP_SUPPORT = True
@@ -79,10 +87,16 @@ __docformat__ = 'restructuredtext'
 def process_www_authenticate(v):
     if not v:
         return []
+    # TODO: provide proper parsing/handling of this custom format and wider support:
+    #   <type> realm=<realm>[, charset="UTF-8"]
+    # More notes: https://github.com/datalad/datalad/issues/5846#issuecomment-890221053
+    # The most complete solution is from 2018 on https://stackoverflow.com/a/52462292/1265472
+    # relying on parsing it using pyparsing.
     supported_type = v.split(' ')[0].lower()
     our_type = {
         'basic': 'http_basic_auth',
         'digest': 'http_digest_auth',
+        # TODO: bearer_token_anon ?
     }.get(supported_type)
     return [our_type] if our_type else []
 
@@ -338,6 +352,18 @@ class HTTPAuthAuthenticator(HTTPRequestsAuthenticator):
         session.auth = authenticator
         response = session.post(post_url, data={},
                                 auth=authenticator)
+        auth_request = response.headers.get('www-authenticate')
+        if response.status_code == 401 and auth_request:
+            if auth_request.lower().split(' ', 1)[0] == 'basic':
+                if response.url != post_url:
+                    # was instructed to authenticate elsewhere
+                    # TODO: do we need to loop may be??
+                    response2 = session.get(response.url, auth=authenticator)
+                    return response2
+            else:
+                lgr.warning(
+                    f"{self} received response with www-authenticate={auth_request!r} "
+                    "which is not Basic, and thus it cannot handle ATM.")
         return response
 
 
@@ -388,6 +414,9 @@ class HTTPAnonBearerTokenAuthenticator(HTTPBearerTokenAuthenticator):
                 .format(status, url))
 
         lgr.debug("Requesting authorization token for %s", url)
+        # TODO: it is not RFC 2068 Section 2 format, but a custom
+        # <type> realm=<realm>[, charset="UTF-8"]
+        # see TODO/harmonize with  process_www_authenticate
         auth_parts = parse_dict_header(response.headers["www-authenticate"])
         auth_url = ("{}?service={}&scope={}"
                     .format(auth_parts["Bearer realm"],
@@ -488,9 +517,20 @@ class HTTPDownloader(BaseDownloader):
     """
 
     @borrowkwargs(BaseDownloader)
-    def __init__(self, headers={}, **kwargs):
+    def __init__(self, headers=None, **kwargs):
+        """
+
+        Parameters
+        ----------
+        headers: dict, optional
+          Header fields to be provided to the session. Unless User-Agent provided, a custom
+          one, available in `DEFAULT_USER_AGENT` constant of this module will be used.
+        """
         super(HTTPDownloader, self).__init__(**kwargs)
         self._session = None
+        headers = headers.copy() if headers else {}
+        if 'user-agent' not in map(str.lower, headers):
+            headers['User-Agent'] = DEFAULT_USER_AGENT
         self._headers = headers
 
     def _establish_session(self, url, allow_old=True):
@@ -526,6 +566,7 @@ class HTTPDownloader(BaseDownloader):
 
         lgr.debug("http session: Creating brand new session")
         self._session = requests.Session()
+        self._session.headers.update(self._headers)
         if self.authenticator:
             self.authenticator.authenticate(url, self.credential, self._session)
 
@@ -543,6 +584,7 @@ class HTTPDownloader(BaseDownloader):
             headers = {}
         if 'Accept-Encoding' not in headers:
             headers['Accept-Encoding'] = ''
+
         # TODO: our tests ATM aren't ready for retries, thus altogether disabled for now
         nretries = 1
         for retry in range(1, nretries+1):
