@@ -261,7 +261,7 @@ def test_access_denied(toppath, topurl, keyring):
 
 
 @with_tempfile(mkdir=True)
-def check_download_external_url(url, failed_str, success_str, d, url_final=None):
+def check_download_external_url(url, failed_str, success_str, d, url_final=None, check_mtime=True):
     fpath = opj(d, get_url_straight_filename(url))
     providers = get_test_providers(url)  # url for check of credentials
     provider = providers.get_provider(url)
@@ -311,7 +311,7 @@ def check_download_external_url(url, failed_str, success_str, d, url_final=None)
     # Verify status
     status = downloader.get_status(url)
     assert(isinstance(status, FileStatus))
-    if not url.startswith('ftp://'):
+    if not url.startswith('ftp://') and check_mtime:
         # TODO introduce support for mtime into requests_ftp?
         assert(status.mtime)
     assert(status.size)
@@ -324,6 +324,16 @@ def check_download_external_url(url, failed_str, success_str, d, url_final=None)
     # TODO -- more and more specific
 
 
+def check_download_external_url_no_mtime(*args, **kwargs):
+    """A helper to be used in generator tests
+
+    since Yarik doesn't know if it is possible to pass optional args,
+    and @with_tempfile sticks itself at the end of *args
+    """
+    kwargs['check_mtime'] = False
+    return check_download_external_url(*args, **kwargs)
+
+
 # TODO: @use_cassette is not playing nice with generators, causing
 # troubles when trying to cause test skip if no network. So disabling for now
 # https://github.com/datalad/datalad/issues/3158
@@ -343,6 +353,12 @@ def test_authenticate_external_portals():
           'https://db.humanconnectome.org/data/experiments/ConnectomeDB_E09797/resources/166768/files/filescans.csv', \
           "failed", \
           "'Scan','FilePath'"
+
+    yield check_download_external_url_no_mtime, \
+        "https://n5eil01u.ecs.nsidc.org/ICEBRIDGE/IDBMG4.004/1993.01.01/BedMachineGreenland-2021-04-20.nc.xml", \
+        'input type="password"', \
+        'DOCTYPE GranuleMetaDataFile'
+
 test_authenticate_external_portals.tags = ['external-portal', 'network']
 
 
