@@ -52,6 +52,7 @@ from datalad.support.sshconnector import get_connection_hash
 from datalad.utils import (
     chpwd,
     get_linux_distribution,
+    on_windows,
     rmtree,
     unlink,
     Path,
@@ -73,6 +74,7 @@ from datalad.tests.utils import (
     assert_true,
     create_tree,
     DEFAULT_BRANCH,
+    DEFAULT_REMOTE,
     eq_,
     find_files,
     get_most_obscure_supported_name,
@@ -1160,10 +1162,10 @@ def test_annex_ssh(topdir):
     topdir = Path(topdir)
     rm1 = AnnexRepo(topdir / "remote1", create=True)
     rm2 = AnnexRepo.clone(rm1.path, str(topdir / "remote2"))
-    rm2.remove_remote("origin")
+    rm2.remove_remote(DEFAULT_REMOTE)
 
     main_tmp = AnnexRepo.clone(rm1.path, str(topdir / "main"))
-    main_tmp.remove_remote("origin")
+    main_tmp.remove_remote(DEFAULT_REMOTE)
     repo_path = main_tmp.path
     del main_tmp
     remote_1_path = rm1.path
@@ -1292,6 +1294,7 @@ def test_repo_version(path1, path2, path3):
             eq_(version, 5)
 
 
+@skip_if(external_versions['cmd:annex'] > '8.20210428', "Stopped showing if too quick")
 @with_tempfile
 def test_init_scanning_message(path):
     # | begin kludge
@@ -1305,7 +1308,11 @@ def test_init_scanning_message(path):
     # | end kludge
     with swallow_logs(new_level=logging.INFO) as cml:
         AnnexRepo(path, create=True, version=7)
-        assert_in("for unlocked", cml.out)
+        # somewhere around 8.20210428-186-g428c91606 git annex changed
+        # handling of scanning for unlocked files upon init and started to report
+        # "scanning for annexed" instead of "scanning for unlocked".
+        # Could be a line among many (as on Windows) so match=False so we search
+        assert_re_in(".*scanning for .* files", cml.out, flags=re.IGNORECASE, match=False)
 
 
 @with_tempfile
@@ -1504,7 +1511,7 @@ def test_is_available(batch, p):
     assert is_available(fname) is True
 
     # known remote but doesn't have it
-    assert is_available(fname, remote='origin') is False
+    assert is_available(fname, remote=DEFAULT_REMOTE) is False
     # it is on the 'web'
     assert is_available(fname, remote='web') is True
     # not effective somehow :-/  may be the process already running or smth
@@ -1922,7 +1929,7 @@ def test_wanted(path):
     GitRepo.clone(ar.path, ar1_path)
     ar1 = AnnexRepo(ar1_path, init=False)
     eq_(ar1.get_preferred_content('wanted'), None)
-    eq_(ar1.get_preferred_content('wanted', 'origin'), v)
+    eq_(ar1.get_preferred_content('wanted', DEFAULT_REMOTE), v)
     ar1.set_preferred_content('wanted', expr='standard')
     eq_(ar1.get_preferred_content('wanted'), 'standard')
 
@@ -2065,7 +2072,8 @@ def test_AnnexRepo_get_tracking_branch(src_path, path):
     ar = AnnexRepo.clone(src_path, path)
 
     # we want the relation to original branch, e.g. in v6+ adjusted branch
-    eq_(('origin', 'refs/heads/' + DEFAULT_BRANCH), ar.get_tracking_branch())
+    eq_((DEFAULT_REMOTE, 'refs/heads/' + DEFAULT_BRANCH),
+        ar.get_tracking_branch())
 
 
 @skip_if_adjusted_branch
@@ -2097,7 +2105,7 @@ def test_is_special(path):
     ok_(rem.is_special_annex_remote("imspecial"))
 
     ar = AnnexRepo.clone(rem.path, op.join(path, "main"))
-    assert_false(ar.is_special_annex_remote("origin"))
+    assert_false(ar.is_special_annex_remote(DEFAULT_REMOTE))
 
     assert_false(ar.is_special_annex_remote("imspecial",
                                             check_if_known=False))
@@ -2105,9 +2113,9 @@ def test_is_special(path):
     ok_(ar.is_special_annex_remote("imspecial"))
 
     # With a mis-configured remote, give warning and return false.
-    ar.config.unset("remote.origin.url", where="local")
+    ar.config.unset(f"remote.{DEFAULT_REMOTE}.url", where="local")
     with swallow_logs(new_level=logging.WARNING) as cml:
-        assert_false(ar.is_special_annex_remote("origin"))
+        assert_false(ar.is_special_annex_remote(DEFAULT_REMOTE))
         cml.assert_logged(msg=".*no URL.*", level="WARNING", regex=True)
 
 
@@ -2347,14 +2355,24 @@ def test_files_split_exc():
     for cls in GitRepo, AnnexRepo:
         yield check_files_split_exc, cls
 
+# with 204  (/ + (98+3)*2 + /) chars guaranteed, we hit "filename too long" quickly on windows
+# so we are doomed to shorten the filepath for testing on windows. Since the limits are smaller
+# on windows (16k vs e.g. 1m on linux in CMD_MAX_ARG), it would already be a "struggle" for it,
+# we also reduce number of dirs/files
+_ht_len, _ht_n = (48, 20) if on_windows else (98, 100)
 
 _HEAVY_TREE = {
     # might already run into 'filename too long' on windows probably
-    "d" * 98 + '%03d' % d: {
-        'f' * 98 + '%03d' % f: ''
-        for f in range(100)
+    "d" * _ht_len + '%03d' % d: {
+        # populate with not entirely unique but still not all identical (empty) keys.
+        # With content unique to that filename we would still get 100 identical
+        # files for each key, thus possibly hitting regressions in annex like
+        # https://git-annex.branchable.com/bugs/significant_performance_regression_impacting_datal/
+        # but also would not hit filesystem as hard as if we had all the keys unique.
+        'f' * _ht_len + '%03d' % f: str(f)
+        for f in range(_ht_n)
     }
-    for d in range(100)
+    for d in range(_ht_n)
 }
 
 
@@ -2378,7 +2396,7 @@ def check_files_split(cls, topdir):
     dl.save(dataset=r.path, path=dirs)
 
 
-@known_failure_windows  # does not find files to add (too long paths?)
+# @known_failure_windows  # might fail with some older annex `cp` failing to set permissions
 @slow  # 313s  well -- if errors out - only 3 sec
 def test_files_split():
     for cls in GitRepo, AnnexRepo:
@@ -2411,7 +2429,7 @@ def test_ro_operations(path):
     # progress forward original repo and fetch (but nothing else) it into repo2
     repo.add('file2')
     repo.commit()
-    repo2.fetch('origin')
+    repo2.fetch(DEFAULT_REMOTE)
 
     # Assure that regardless of umask everyone could read it all
     run(['chmod', '-R', 'a+rX', repo2.path])
