@@ -8,8 +8,11 @@
 # ## ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ### ##
 
 from ..status import FileStatus
-from ...tests.utils import assert_equal, assert_false
-from nose.tools import assert_not_equal
+from datalad.tests.utils import (
+    assert_equal,
+    assert_not_equal,
+)
+
 
 def test_FileStatus_basic():
     assert_equal(FileStatus(size=0), FileStatus(size=0))
